# ModelJoinedModelJobResponseDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**feature_sub_categories** | [**ModelJoinedModelJobJoinedFeatureSubCategoryResponseDto**](ModelJoinedModelJobJoinedFeatureSubCategoryResponseDto.md) |  | [optional] 
**dataset** | [**ModelJoinedModelJobJoinedDatasetResponseDto**](ModelJoinedModelJobJoinedDatasetResponseDto.md) |  | [optional] 
**cohort** | [**ModelJoinedModelJobJoinedCohortResponseDto**](ModelJoinedModelJobJoinedCohortResponseDto.md) |  | [optional] 
**id** | **str** |  | [optional] 
**type** | **str** |  | 
**outcome_type** | **str** |  | [optional] 
**config** | [**ModelJobConfig**](ModelJobConfig.md) |  | [optional] 
**execution_id** | **str** |  | [optional] 
**status** | **str** |  | [optional] 
**project_id** | **str** |  | 
**model_id** | **str** |  | 
**cohort_id** | **str** |  | [optional] 
**dataset_id** | **str** |  | [optional] 
**model_population_id** | **str** |  | [optional] 
**outcome_distribution_histogram_query_id** | **str** |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**started_at** | **datetime** |  | [optional] 
**ended_at** | **datetime** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

